@@ -1,4 +1,4 @@
-/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 8-*- */
+/* -*- Mode: C++; indent-tabs-mode: nil; c-basic-offset: 4-*- */
 
 /*This file is part of MlView
  *
@@ -34,9 +34,9 @@ G_BEGIN_DECLS
 #  define MLVIEW_IS_ATTRIBUTE_PICKER_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), MLVIEW_TYPE_ATTRIBUTE_PICKER))
 typedef struct _MlViewAttributePicker MlViewAttributePicker;
 typedef struct _MlViewAttributePickerClass
- MlViewAttributePickerClass;
+			MlViewAttributePickerClass;
 typedef struct _MlViewAttributePickerPrivate
- MlViewAttributePickerPrivate;
+			MlViewAttributePickerPrivate;
 
 /**
  *The attribute picker of mlview.
@@ -45,61 +45,56 @@ typedef struct _MlViewAttributePickerPrivate
  *the xmlNode on which the attribute is to be defined.
  *This class inherits the GnomDialog class.
  */
-struct _MlViewAttributePicker {
-        /**The parent class*/
-        GtkDialog dialog;
-        /**The private members of this class*/
-        MlViewAttributePickerPrivate *private;
+struct _MlViewAttributePicker
+{
+	/**The parent class*/
+	GtkDialog dialog;
+	/**The private members of this class*/
+	MlViewAttributePickerPrivate *priv;
 };
 
 gint mlview_attribute_picker_get_type (void);
 
-GtkWidget *mlview_attribute_picker_new (gchar * a_title,
-                                        MlViewAppContext *
-                                        a_app_context);
+GtkWidget *mlview_attribute_picker_new (gchar * a_title);
 
 void
- mlview_attribute_picker_set_attribute_completion (gboolean a_completion_on);
+mlview_attribute_picker_set_attribute_completion (gboolean a_completion_on);
 
 void
- mlview_attribute_picker_grab_focus_to_name_entry (MlViewAttributePicker * a_picker);
+mlview_attribute_picker_grab_focus_to_name_entry (MlViewAttributePicker * a_picker);
 
 void
- mlview_attribute_picker_grab_focus_to_value_entry (MlViewAttributePicker * a_picker);
+mlview_attribute_picker_grab_focus_to_value_entry (MlViewAttributePicker * a_picker);
 
 void
- mlview_attribute_picker_select_attribute_value (MlViewAttributePicker * a_picker);
+mlview_attribute_picker_select_attribute_value (MlViewAttributePicker * a_picker);
 
 void
- mlview_attribute_picker_select_attribute_name (MlViewAttributePicker * a_picker);
+mlview_attribute_picker_select_attribute_name (MlViewAttributePicker * a_picker);
 
-guchar *mlview_attribute_picker_get_attribute_name
-        (MlViewAttributePicker * a_picker);
+gchar *mlview_attribute_picker_get_attribute_name
+(MlViewAttributePicker * a_picker);
 
-guchar *mlview_attribute_picker_get_attribute_value
-        (MlViewAttributePicker * a_picker);
+gchar *mlview_attribute_picker_get_attribute_value
+(MlViewAttributePicker * a_picker);
 
 xmlAttributeType
 mlview_attribute_picker_get_attribute_type (MlViewAttributePicker
-                                            * a_picker);
+        * a_picker);
 
-void
- mlview_attribute_picker_build_attribute_name_choice_list (MlViewAttributePicker * a_picker,
-                                                           xmlNode
-                                                           *
-                                                           a_xml_node);
+void mlview_attribute_picker_build_attribute_name_choice_list
+(MlViewAttributePicker * a_picker,
+ xmlNode * a_xml_node);
 
-void
- mlview_attribute_picker_set_current_xml_node (MlViewAttributePicker * a_picker,
-                                               xmlNode *
-                                               a_xml_node);
-void
- mlview_attribute_picker_set_app_context (MlViewAttributePicker * a_picker,
-                                          MlViewAppContext *
-                                          a_app_context);
+void mlview_attribute_picker_set_current_xml_node
+(MlViewAttributePicker * a_picker,
+ xmlNode * a_xml_node);
 
-struct _MlViewAttributePickerClass {
-        GtkDialogClass parent_class;
+void mlview_attribute_picker_set_app_context (MlViewAttributePicker * a_picker);
+
+struct _MlViewAttributePickerClass
+{
+	GtkDialogClass parent_class;
 };
 
 G_END_DECLS
