@@ -32,6 +32,7 @@
 /*#include <sys/stat.h>
   #include <fcntl.h>*/
 
+G_BEGIN_DECLS
 
 /**
  *@file
@@ -48,8 +49,9 @@ typedef struct _MlViewFileDescriptorPrivate MlViewFileDescriptorPrivate;
  *should be made via the apis exposed by this object. The api is far 
  *from being complete but MlView uses it to have infos about the local files.
  */
-struct _MlViewFileDescriptor {
-        MlViewFileDescriptorPrivate *priv;
+struct _MlViewFileDescriptor
+{
+	MlViewFileDescriptorPrivate *priv;
 };
 
 MlViewFileDescriptor *mlview_file_descriptor_new (const gchar *a_file_path);
@@ -61,19 +63,21 @@ gchar *mlview_file_descriptor_get_uri (const MlViewFileDescriptor *a_file_desc);
 gchar *mlview_file_descriptor_get_file_path (const MlViewFileDescriptor *a_file_desc);
 
 void mlview_file_descriptor_set_file_path (MlViewFileDescriptor * a_file_desc,
-                                           const gchar * file_path);
+        const gchar * file_path);
 
 void mlview_file_descriptor_update_modified_time (MlViewFileDescriptor * a_file_desc);
 
 gint mlview_file_descriptor_is_modified (const MlViewFileDescriptor * a_file_desc,
-                                         gboolean * a_is_modified);
+        gboolean * a_is_modified);
 
 gint mlview_file_descriptor_is_regular_file (const MlViewFileDescriptor * a_file_desc,
-                                             gboolean * a_is_reg);
+        gboolean * a_is_reg);
 
 gint mlview_file_descriptor_is_local (MlViewFileDescriptor * a_file_desc,
                                       gboolean * a_is_local);
 
 gchar * mlview_file_descriptor_get_mime_type (MlViewFileDescriptor * a_file_desc);
 
+G_END_DECLS
+
 #endif
