@@ -44,18 +44,19 @@ G_BEGIN_DECLS
 
 /*The data structure to define xml node types*/
 typedef struct _NodeTypeDefinition NodeTypeDefinition;
-struct _NodeTypeDefinition {
-        const char *node_type_name;
-        xmlElementType node_type ;
-        xmlEntityType entity_type ;
+struct _NodeTypeDefinition
+{
+	const char *node_type_name;
+	xmlElementType node_type ;
+	xmlEntityType entity_type ;
 };
 
 typedef struct _MlViewNodeTypePicker
-MlViewNodeTypePicker;
+			MlViewNodeTypePicker;
 typedef struct _MlViewNodeTypePickerClass
-MlViewNodeTypePickerClass;
+			MlViewNodeTypePickerClass;
 typedef struct _MlViewNodeTypePickerPrivate
-MlViewNodeTypePickerPrivate;
+			MlViewNodeTypePickerPrivate;
 
 /**
  *The MlViewNodeTypePicker class.
@@ -64,13 +65,15 @@ MlViewNodeTypePickerPrivate;
  *into the xml document. This class also provides methods
  *to get the type of node the user has choosen.
  */
-struct _MlViewNodeTypePicker {
+struct _MlViewNodeTypePicker
+{
 	GtkDialog dialog;
 	MlViewNodeTypePickerPrivate *priv;
 };
 
 /*The MlViewNodeTypePicker class definition */
-struct _MlViewNodeTypePickerClass {
+struct _MlViewNodeTypePickerClass
+{
 	GtkDialogClass parent_class;
 	/*any signal handler shoud come here */
 };
@@ -85,35 +88,27 @@ gchar *mlview_node_type_picker_get_selected_node_type_name (MlViewNodeTypePicker
 gchar *mlview_node_type_picker_get_node_name_or_content (MlViewNodeTypePicker * a_nt_picker);
 
 void mlview_node_type_picker_set_selected_node_type (MlViewNodeTypePicker * a_nt_picker,
-						     xmlElementType a_node_type,
-						     xmlEntityType a_entity_type);
+        xmlElementType a_node_type,
+        xmlEntityType a_entity_type);
 
 void mlview_node_type_picker_set_focus_to_node_name_or_content_entry (MlViewNodeTypePicker * a_nt_picker);
 
 void mlview_node_type_picker_select_node_name_or_content_entry_text (MlViewNodeTypePicker * a_nt_picker);
 
-GtkWidget *mlview_node_type_picker_new (MlViewAppContext * a_app_context);
+GtkWidget *mlview_node_type_picker_new ();
 
-GtkWidget *mlview_node_type_picker_new_with_title (gchar
-						   *
-						   a_title,
-						   MlViewAppContext
-						   *
-						   a_app_context);
-void
-mlview_node_type_picker_set_on_going_validation
-(gboolean a_on);
+GtkWidget *mlview_node_type_picker_new_with_title (gchar*a_title);
 
-gboolean
-mlview_node_type_picker_on_going_validation_is_on
-(void);
+void mlview_node_type_picker_set_on_going_validation (gboolean a_on);
+
+gboolean mlview_node_type_picker_on_going_validation_is_on (void);
 
 void mlview_node_type_picker_set_title (MlViewNodeTypePicker * a_nt_picker,
 					const gchar * a_title);
-void
-mlview_node_type_picker_build_element_name_choice_list (MlViewNodeTypePicker * a_picker,
-							enum NODE_INSERTION_SCHEME a_insertion_scheme,
-							xmlNode * a_current_xml_node);
+
+void mlview_node_type_picker_build_element_name_choice_list (MlViewNodeTypePicker * a_picker,
+							     enum NODE_INSERTION_SCHEME a_insertion_scheme,
+							     xmlNode * a_current_xml_node);
 
 G_END_DECLS
 #endif                          /*MLVIEW_ELEMENT_TYPE_PICKER */
