@@ -30,8 +30,7 @@
 
 G_BEGIN_DECLS
 
-GtkWidget *mlview_schemas_window_new_with_document (MlViewXMLDocument *a_doc,
-                                                    MlViewAppContext *a_ctxt);
+GtkWidget *mlview_schemas_window_new_with_document (MlViewXMLDocument *a_doc);
 
 G_END_DECLS
 
