@@ -43,53 +43,55 @@ typedef struct _MlViewStyledView MlViewStyledView ;
 typedef struct _MlViewStyledViewClass MlViewStyledViewClass ;
 typedef struct _MlViewStyledViewPriv MlViewStyledViewPriv ;
 
-struct _MlViewStyledView {
+struct _MlViewStyledView
+{
 	MlViewViewAdapter view ;
 	MlViewStyledViewPriv *priv ;
 } ;
 
-struct _MlViewStyledViewClass {
+struct _MlViewStyledViewClass
+{
 	MlViewViewAdapterClass parent_class ;
 	/*signal default handlers*/
 } ;
 
 GType mlview_styled_view_get_type (void) ;
 GtkWidget *mlview_styled_view_new (MlViewXMLDocument *a_doc,
-				   const gchar *a_name,
-				   MlViewAppContext *a_app_ctxt) ;
+                                   const gchar *a_name,
+                                   MlViewAppContext *a_app_ctxt) ;
 
 MlViewTreeEditor *mlview_styled_view_get_tree_editor (MlViewStyledView *a_this) ;
 
 enum MlViewStatus mlview_styled_view_construct (MlViewStyledView *a_this,
-						MlViewXMLDocument *a_doc,
-						const guchar *a_view_name,
-						MlViewAppContext *a_app_context) ;
+        MlViewXMLDocument *a_doc,
+        const gchar *a_view_name,
+        MlViewAppContext *a_app_context) ;
 
 enum MlViewStatus mlview_styled_view_create_internal_subset_node_interactive (MlViewStyledView *a_this) ;
 
 enum MlViewStatus mlview_styled_view_execute_action (MlViewIView *a_this,
-                                                     MlViewAction *a_action) ;
+        MlViewAction *a_action) ;
 
 enum MlViewStatus mlview_styled_view_connect_to_doc (MlViewIView *a_this,
-                                                     MlViewXMLDocument *a_doc) ;
+        MlViewXMLDocument *a_doc) ;
 
 enum MlViewStatus mlview_styled_view_disconnect_from_doc (MlViewIView *a_this,
-                                                          MlViewXMLDocument *a_doc) ;
+        MlViewXMLDocument *a_doc) ;
 
 enum MlViewStatus mlview_styled_view_update_from_css_paths (MlViewStyledView *a_this,
-                                                            guchar *a_author_css_path,
-                                                            guchar *a_user_css_path,
-                                                            guchar *a_ua_css_path,
-                                                            enum CREncoding a_enc) ;
+        gchar *a_author_css_path,
+        gchar *a_user_css_path,
+        gchar *a_ua_css_path,
+        enum CREncoding a_enc) ;
 
 enum MlViewStatus mlview_styled_view_updatde_from_cascade (MlViewStyledView *a_this,
-                                                           CRCascade *a_cascade) ;
+        CRCascade *a_cascade) ;
 
 enum MlViewStatus mlview_styled_view_update_from_css_paths_interactive (MlViewStyledView *a_this) ;
 
 
 enum MlViewStatus mlview_styled_view_set_app_context (MlViewStyledView *a_this,
-                                                      MlViewAppContext *a_app_context) ;
+        MlViewAppContext *a_app_context) ;
 
 MlViewAppContext * mlview_styled_view_get_app_context (MlViewStyledView *a_this) ;
 
